@@ -29,7 +29,11 @@ INS_UNBLOCK_PIN: int = 0x22
 INS_STORE_DATA: int = 0xE2
 INS_GET_DATA: int = 0xCA
 INS_SIGN: int = 0xC0
+INS_SET_PINLESS_PATH = 0xC1
 INS_EXPORT_KEY: int = 0xC2
+INS_LOAD_KEY: int = 0xD0
+INS_DERIVE_KEY = 0xD1
+INS_GENERATE_MNEMONIC = 0xD2
 
 # Status words
 SW_SUCCESS: int = 0x9000
@@ -71,3 +75,9 @@ class SigningAlgorithm(IntEnum):
     EDDSA_ED25519 = 0x01
     BLS12_381 = 0x02
     SCHNORR_BIP340 = 0x03
+
+
+class LoadKeyType(IntEnum):
+    ECC = 0x01
+    EXTENDED_ECC = 0x02
+    BIP39_SEED = 0x03
