@@ -1,13 +1,13 @@
+from types import TracebackType
 from typing import Optional, Union
 
 from . import constants
 from . import commands
 from .apdu import APDUResponse
-from .constants import DerivationOption, SigningAlgorithm
+from .constants import DerivationOption
 from .card_interface import CardInterface
 from .exceptions import APDUError
 from .parsing.application_info import ApplicationInfo
-from .parsing.identity import Identity
 from .parsing.exported_key import ExportedKey
 from .parsing.signature_result import SignatureResult
 from .transport import Transport
@@ -22,7 +22,7 @@ class KeyCard(CardInterface):
     and card operations.
     '''
 
-    def __init__(self, transport: Transport):
+    def __init__(self, transport: Optional[Transport] = None):
         '''
         Initializes the KeyCard interface.
 
@@ -32,14 +32,24 @@ class KeyCard(CardInterface):
         Raises:
             ValueError: If transport is None.
         '''
-        if not transport:
-            raise ValueError('Transport not initialized')
-
-        self.transport = transport
+        self.transport = transport if transport else Transport()
         self.card_public_key: Optional[bytes] = None
         self.session: Optional[SecureChannel] = None
         self._is_pin_verified: bool = False
 
+    def __enter__(self) -> 'KeyCard':
+        self.transport.connect()
+        return self
+
+    def __exit__(
+        self,
+        type_: type[BaseException] | None,
+        value: BaseException | None,
+        traceback: TracebackType | None
+    ) -> None:
+        if self.transport:
+            self.transport.disconnect()
+
     @property
     def is_selected(self) -> bool:
         '''
@@ -118,22 +128,24 @@ class KeyCard(CardInterface):
             pairing_secret,
         )
 
-    def ident(self, challenge: bytes) -> Identity:
+    def ident(self, challenge: Optional[bytes] = None) -> bytes:
         '''
         Sends an identity challenge to the card.
 
         Args:
-            challenge (bytes): Challenge data to sign.
+            challenge (bytes): A challenge (nonce or data) to send to the
+                card. If None, a random 32-byte challenge is generated.
 
         Returns:
-            bytes: Response data (e.g., signature or proof).
+            bytes: The public key extracted from the card's identity response.
         '''
         return commands.ident(self, challenge)
 
     def open_secure_channel(
         self,
         pairing_index: int,
-        pairing_key: bytes
+        pairing_key: bytes,
+        mutually_authenticate: Optional[bool] = True
     ) -> None:
         '''
         Opens a secure session with the card.
@@ -141,6 +153,8 @@ class KeyCard(CardInterface):
         Args:
             pairing_index (int): Index of the pairing slot to use.
             pairing_key (bytes): The shared pairing key (32 bytes).
+            mutually_authenticate (bool): Execute mutually authenticate when
+                a secure channel has been opened
         '''
         self.session = commands.open_secure_channel(
             self,
@@ -148,6 +162,9 @@ class KeyCard(CardInterface):
             pairing_key,
         )
 
+        if mutually_authenticate:
+            self.mutually_authenticate()
+
     def mutually_authenticate(self) -> None:
         '''
         Performs mutual authentication between host and card.
@@ -412,7 +429,6 @@ class KeyCard(CardInterface):
     def sign(
         self,
         digest: bytes,
-        algo: SigningAlgorithm = SigningAlgorithm.ECDSA_SECP256K1
     ) -> SignatureResult:
         """
         Sign using the currently loaded keypair.
@@ -420,21 +436,19 @@ class KeyCard(CardInterface):
 
         Args:
             digest (bytes): 32-byte hash to sign
-            algo (SigningAlgorithm): algorithm to use (default ECDSA/secp256k1)
 
         Returns:
             SignatureResult: Parsed signature result, including the signature
                 (DER or raw), algorithm, and optional recovery ID or
                 public key.
         """
-        return commands.sign(self, digest, DerivationOption.CURRENT, algo)
+        return commands.sign(self, digest, DerivationOption.CURRENT)
 
     def sign_with_path(
         self,
         digest: bytes,
         path: str,
-        make_current: bool = False,
-        algo: SigningAlgorithm = SigningAlgorithm.ECDSA_SECP256K1
+        make_current: bool = False
     ) -> SignatureResult:
         """
         Sign using a derived keypath. Optionally updates the current path.
@@ -443,7 +457,6 @@ class KeyCard(CardInterface):
             digest (bytes): 32-byte hash to sign
             path (list[int]): list of 32-bit integers
             make_current (bool): whether to update current path on card
-            algo (SigningAlgorithm): signature algorithm
 
         Returns:
             SignatureResult: Parsed signature result, including the signature
@@ -454,12 +467,11 @@ class KeyCard(CardInterface):
             DerivationOption.DERIVE_AND_MAKE_CURRENT
             if make_current else DerivationOption.DERIVE
         )
-        return commands.sign(self, digest, p1, algo, derivation_path=path)
+        return commands.sign(self, digest, p1, derivation_path=path)
 
     def sign_pinless(
         self,
-        digest: bytes,
-        algo: SigningAlgorithm = SigningAlgorithm.ECDSA_SECP256K1
+        digest: bytes
     ) -> SignatureResult:
         """
         Sign using the predefined PIN-less path.
@@ -467,7 +479,6 @@ class KeyCard(CardInterface):
 
         Args:
             digest (bytes): 32-byte hash to sign
-            algo (SigningAlgorithm): signature algorithm
 
         Returns:
             SignatureResult: Parsed signature result, including the signature
@@ -477,7 +488,72 @@ class KeyCard(CardInterface):
         Raises:
             APDUError: if no PIN-less path is set
         """
-        return commands.sign(self, digest, DerivationOption.PINLESS, algo)
+        return commands.sign(self, digest, DerivationOption.PINLESS)
+
+    def load_key(
+        self,
+        key_type: constants.LoadKeyType,
+        public_key: Optional[bytes] = None,
+        private_key: Optional[bytes] = None,
+        chain_code: Optional[bytes] = None,
+        bip39_seed: Optional[bytes] = None
+    ) -> bytes:
+        """
+        Load a key into the card for signing purposes.
+
+        Args:
+            key_type: Key type
+            public_key: Optional ECC public key (tag 0x80).
+            private_key: ECC private key (tag 0x81).
+            chain_code: Optional chain code (tag 0x82, only for extended key).
+            bip39_seed: 64-byte BIP39 seed (only for key_type=BIP39_SEED).
+
+        Returns:
+            UID of the loaded key (SHA-256 of public key).
+        """
+        return commands.load_key(
+            self,
+            key_type=key_type,
+            public_key=public_key,
+            private_key=private_key,
+            chain_code=chain_code,
+            bip39_seed=bip39_seed
+        )
+
+    def set_pinless_path(self, path: str) -> None:
+        """
+        Set a PIN-less path on the card. Allows signing without PIN/auth if the
+        current derived key matches this path.
+
+        Args:
+            path (str): BIP-32-style path (e.g., "m/44'/60'/0'/0/0"). An empty
+                        string disables the pinless path.
+        """
+        commands.set_pinless_path(self, path)
+
+    def generate_mnemonic(self, checksum_size: int = 6) -> list[int]:
+        """
+        Generate a BIP39 mnemonic using the card's RNG.
+
+        Args:
+            checksum_size (int): Number of checksum bits
+                (between 4 and 8 inclusive).
+
+        Returns:
+            List[int]: List of integers (0-2047) corresponding to wordlist
+                indexes.
+        """
+        return commands.generate_mnemonic(self, checksum_size)
+
+    def derive_key(self, path: str = '') -> None:
+        """
+        Set the derivation path for subsequent SIGN and EXPORT KEY commands.
+
+        Args:
+            path (str): BIP-32-style path (e.g., "m/44'/60'/0'/0/0") or
+                        "../0/1" (parent) or "./0" (current).
+        """
+        commands.derive_key(self, path)
 
     def send_apdu(
         self,
